==> framework_2.6.tar.gz: java/bioLegato.0.6.2/src/GDECanvas/src/org/biolegato/gdesupport/canvas/colourmap/MonochromeColourMap.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package org.biolegato.gdesupport.canvas.colourmap;

import org.biolegato.gdesupport.canvas.textarea.BLTextArea;
import java.awt.Color;
import java.awt.Graphics;
import org.biolegato.core.data.sequence.Sequence;

/**
 * A standard monochrome colour map.
 *
 * @author Graham Alvare
 * @author Brian Fristensky
 */
public class MonochromeColourMap extends ColourMap {

    /**
     * Creates a new instance of MonochromeColourMap
     */
    public MonochromeColourMap () {
    }

    /**
     * Creates a new instance of MonochromeColourMap
     *
     * @param foreground the colour to use as the foreground for unselected text.
     * @param background the colour to use as the background for unselected text.
     * @param foregroundSelect the colour to use as the foreground for selected text.
     * @param backgroundSelect the colour to use as the background for selected text.
     */
    public MonochromeColourMap (Color foreground, Color background, Color foregroundSelect, Color backgroundSelect) {
        this.foreground = foreground;
        this.background = background;
        this.foregroundSelect = foregroundSelect;
        this.backgroundSelect = backgroundSelect;
    }

    /**
     * Draws a sequence mapping the appropriate colours to each character rendered.
     *
     * @param ta the textarea to use for obtaining metrics from.
     * @param gfx the graphics object to draw the string to.
     * @param xstart the x co-ordinate to start drawing from.
     * @param ystart the y co-ordinate to start drawing from.
     * @param seq the sequence to draw.
     */
    @Override
    public void regularDrawString (BLTextArea ta, Graphics gfx, int xstart, int ystart, Sequence seq) {
        drawString(ta, gfx, xstart, ystart, seq.get("sequence").toString(), foreground, background);
    }
}

==> framework_2.7.tar.gz: java/bioLegato.0.7.0/src/GDECanvas/src/org/biolegato/gdesupport/canvas/colourmap/MonochromeColourMap.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package org.biolegato.gdesupport.canvas.colourmap;

import org.biolegato.gdesupport.canvas.textarea.BLTextArea;
import java.awt.Color;
import java.awt.Graphics;
import org.biolegato.core.data.sequence.Sequence;

/**
 * A standard monochrome colour map.
 *
 * @author Graham Alvare
 * @author Brian Fristensky
 */
public class MonochromeColourMap extends ColourMap {

    /**
     * Creates a new instance of MonochromeColourMap
     */
    public MonochromeColourMap () {
    }

    /**
     * Creates a new instance of MonochromeColourMap
     *
     * @param foreground the colour to use as the foreground for unselected text.
     * @param background the colour to use as the background for unselected text.
     * @param foregroundSelect the colour to use as the foreground for selected text.
     * @param backgroundSelect the colour to use as the background for selected text.
     */
    public MonochromeColourMap (Color foreground, Color background, Color foregroundSelect, Color backgroundSelect) {
        this.foreground = foreground;
        this.background = background;
        this.foregroundSelect = foregroundSelect;
        this.backgroundSelect = backgroundSelect;
    }

    /**
     * Draws a sequence mapping the appropriate colours to each character rendered.
     *
     * @param ta the textarea to use for obtaining metrics from.
     * @param gfx the graphics object to draw the string to.
     * @param xstart the x co-ordinate to start drawing from.
     * @param ystart the y co-ordinate to start drawing from.
     * @param seq the sequence to draw.
     */
    @Override
    public void regularDrawString (BLTextArea ta, Graphics gfx, int xstart, int ystart, Sequence seq, int pstart, int pend) {
	char[] array = safesubstring(seq, pstart, pend).toCharArray();
        drawChars(ta, gfx, xstart, ystart, array, 0, array.length, foreground, background);
    }
}
